# -*- Mode: Python -*-
# -*- coding: utf-8 -*-
"""
This is a LightWave Command Sequence plug-in (Modeler)
"""

import sys
import lwsdk

__author__     = "Shu"
__date__       = "April 18 2023"
__version__    = "1.01"
__email__      = "www.m-bros.net/~shu"
__status__     = "Modeler"
__lwver__      = "2020"

class shu_Set_GENOMA_Gizmo(lwsdk.ICommandSequence):
    def __init__(self, context):
        super(shu_Set_GENOMA_Gizmo, self).__init__()

    def fast_poly_scan(self, poly_list, poly_id):
        poly_list.append(poly_id)
        return lwsdk.EDERR_NONE


    # LWCommandSequence -----------------------------------
    def process(self, mod_command):
        mesh_edit_op = mod_command.editBegin(0, 0, lwsdk.OPSEL_USER)
        if not mesh_edit_op:
            print >>sys.stderr, 'Failed to engage mesh edit operations!'
            return lwsdk.AFUNC_OK
            
        lwMF = lwsdk.LWMessageFuncs()
        polys = []

        edit_op_result = mesh_edit_op.fastPolyScan(mesh_edit_op.state, self.fast_poly_scan, (polys,), lwsdk.OPLYR_FG, 1)
        if len(polys) == 0:
            lwMF.info("Error", "No item selected.")
            mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
            return lwsdk.AFUNC_OK
        
        #No Genoma Check
        for poly in polys:
            genoma_info = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','1'))
        
            if genoma_info == None:
                lwMF.info("Error", "No GENOMA Tag existing in this items.")
                mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
                return lwsdk.AFUNC_OK
        
        ui = lwsdk.LWPanels()
        title = 'Set GENOMA Gizmo v%s' %__version__
        panel = ui.create(title)
        
        vis = panel.bool_ctl('Visible')
        vis.set_int(1)
        loc = panel.bool_ctl('Lock')
        ChX = panel.bool_ctl('X ')
        ChY = panel.bool_ctl('Y ')
        ChZ = panel.bool_ctl('Z ')
        ChH = panel.bool_ctl('H ')
        ChP = panel.bool_ctl('P ')
        ChB = panel.bool_ctl('B ')
        ChSX = panel.bool_ctl('SX')
        ChSY = panel.bool_ctl('SY')
        ChSZ = panel.bool_ctl('SZ')
        panel.align_controls_horizontal([vis,loc])
        panel.align_controls_horizontal([ChX,ChH,ChSX])
        panel.align_controls_horizontal([ChY,ChP,ChSY])
        panel.align_controls_horizontal([ChZ,ChB,ChSZ])
        panel.size_to_layout(5, 5)
        if panel.open(lwsdk.PANF_BLOCKING | lwsdk.PANF_CANCEL) == 0:
            ui.destroy(panel)
            mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
            return lwsdk.AFUNC_OK
        
        for poly in polys:
            genoma_info = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','1'))
 
            genoma_info2 = mesh_edit_op.polyTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','2'))
            gInfo = genoma_info.split("#")

            #before status test view. 
            #print>> sys.stderr, "G1:"+ genoma_info
            #print>> sys.stderr, "G2:"+ genoma_info2

            chIndex1 = ChX.get_int()
            chIndex2 = ChY.get_int()
            chIndex3 = ChZ.get_int()
            chIndex4 = ChH.get_int()
            chIndex5 = ChP.get_int()
            chIndex6 = ChB.get_int()
            chIndex7 = ChSX.get_int()
            chIndex8 = ChSY.get_int()
            chIndex9 = ChSZ.get_int()

            gInfo[11] = str(chIndex1) + str(chIndex2) + str(chIndex3) + str(chIndex4) +\
            str(chIndex5) + str(chIndex6) + str(chIndex7) + str(chIndex8) + str(chIndex9)
            gInfo[13] = str(vis.get_int())
            gInfo[15] = str(loc.get_int())
            
            #after status test view
            #print>> sys.stderr,"G2:"+ str(gInfo)
            #print>> sys.stderr, "G3:"+str(chIndex2)
            #print>> sys.stderr, nulShpList
            
            
            genoma_info = "#".join(gInfo)
            mesh_edit_op.polTag(mesh_edit_op.state, poly, lwsdk.LWID_('G','M','0','1'),genoma_info)
            
            
        mesh_edit_op.done(mesh_edit_op.state, edit_op_result, 0)
        return lwsdk.AFUNC_OK


ServerTagInfo = [
                    ( "shu_Set_GENOMA_Gizmo", lwsdk.SRVTAG_USERNAME | lwsdk.LANGID_USENGLISH ),
                    ( "shuGenomaGizmo", lwsdk.SRVTAG_BUTTONNAME | lwsdk.LANGID_USENGLISH ),
                    ( "Utilities/Python", lwsdk.SRVTAG_MENU | lwsdk.LANGID_USENGLISH )
                ]

ServerRecord = { lwsdk.CommandSequenceFactory("LW_PySetGenomaGizmo", shu_Set_GENOMA_Gizmo) : ServerTagInfo }